@@ -69,7 +69,7 @@
 
 		/**
 		 * Keeps track of all modifications on settings which are not saved yet.
-		 * The array is reset in saveSettings() after a succesful save.
+		 * The array is reset in saveSettings() after a successful save.
 		 */
 		private $modified;
 
@@ -81,9 +81,6 @@
 			$this->settings_string = '';
 			$this->modified = array();
 			$this->init = false;
-
-			// Initialize the settings object
-			$this->Init();
 		}
 
 		/**
@@ -126,7 +123,7 @@
 		function get($path=null, $default=null, $persistent=false)
 		{
 			if (!$this->init) {
-				throw new SettingsException(_('Settings object is not initialized'));
+				$this->Init();
 			}
 
 			$settings = !!$persistent ? $this->persistentSettings : $this->settings;
@@ -179,7 +176,7 @@
 		function set($path, $value, $autoSave = false, $persistent=false)
 		{
 			if (!$this->init) {
-				throw new SettingsException(_('Settings object is not initialized'));
+				$this->Init();
 			}
 
 			if ( !!$persistent ){
@@ -190,7 +187,7 @@
 
 			$path = explode('/', $path);
 
-			// Save the last key seperately
+			// Save the last key separately
 			$lastKey = array_pop($path);
 
 			// Walk over the settings to find the object
@@ -246,7 +243,7 @@
 		function delete($path, $autoSave = false)
 		{
 			if (!$this->init) {
-				throw new SettingsException(_('Settings object is not initialized'));
+				$this->Init();
 			}
 
 			$this->modified[$path] = '';
@@ -288,7 +285,7 @@
 		function getJSON()
 		{
 			if (!$this->init) {
-				throw new SettingsException(_('Settings object is not initialized'));
+				$this->Init();
 			}
 
 			return json_encode($this->settings);
@@ -304,7 +301,7 @@
 		function getPersistentSettingsJSON()
 		{
 			if (!$this->init) {
-				throw new SettingsException(_('Settings object is not initialized'));
+				$this->Init();
 			}
 
 			return json_encode($this->persistentSettings);
@@ -379,7 +376,8 @@
 			$storeProps = mapi_getprops($this->store, array(PR_EC_WEBAPP_PERSISTENT_SETTINGS_JSON));
 
 			// Check if property exists, if it does not exist then we can continue with empty set of settings
-			if ( isset($storeProps[PR_EC_WEBAPP_PERSISTENT_SETTINGS_JSON]) ){
+			if ( isset($storeProps[PR_EC_WEBAPP_PERSISTENT_SETTINGS_JSON])
+				|| propIsError(PR_EC_WEBAPP_PERSISTENT_SETTINGS_JSON, $storeProps) == MAPI_E_NOT_ENOUGH_MEMORY ) {
 
 				if ( propIsError(PR_EC_WEBAPP_PERSISTENT_SETTINGS_JSON, $storeProps) == MAPI_E_NOT_ENOUGH_MEMORY ) {
 					$this->persistentSettingsString = streamProperty($this->store, PR_EC_WEBAPP_PERSISTENT_SETTINGS_JSON);
@@ -434,7 +432,7 @@
 		}
 
 		/**
-		 * Applies the default settigns defined by the System Administrator to the sysAdminDefaults
+		 * Applies the default settings defined by the System Administrator to the sysAdminDefaults
 		 * property.
 		 * @param Array $settings The default settings
 		 */
@@ -476,7 +474,7 @@
 		function saveSettings()
 		{
 			if (!$this->init) {
-				throw new SettingsException(_('Settings object is not initialized'));
+				$this->Init();
 			}
 
 			$this->saveExternalSettings();
@@ -499,7 +497,7 @@
 					$GLOBALS["operations"]->publishFreeBusy($this->store);
 				}
 
-				$stream = mapi_openproperty($this->store, PR_EC_WEBACCESS_SETTINGS_JSON, IID_IStream, 0, MAPI_CREATE | MAPI_MODIFY);
+				$stream = mapi_openproperty($this->store, PR_EC_WEBACCESS_SETTINGS_JSON, IID_IStream, STGM_TRANSACTED, MAPI_CREATE | MAPI_MODIFY);
 				mapi_stream_setsize($stream, strlen($settings));
 				mapi_stream_write($stream, $settings);
 				mapi_stream_commit($stream);
@@ -528,7 +526,7 @@
 
 			// Check if the settings have been changed.
 			if ($this->persistentSettingsString !== $persistentSettings) {
-				$stream = mapi_openproperty($this->store, PR_EC_WEBAPP_PERSISTENT_SETTINGS_JSON, IID_IStream, 0, MAPI_CREATE | MAPI_MODIFY);
+				$stream = mapi_openproperty($this->store, PR_EC_WEBAPP_PERSISTENT_SETTINGS_JSON, IID_IStream, STGM_TRANSACTED, MAPI_CREATE | MAPI_MODIFY);
 				mapi_stream_setsize($stream, strlen($persistentSettings));
 				mapi_stream_write($stream, $persistentSettings);
 				mapi_stream_commit($stream);
@@ -640,10 +638,6 @@
 		 */
 		function getSessionSettings($Language)
 		{
-			if (!$this->init) {
-				throw new SettingsException(_('Settings object is not initialized'));
-			}
-
 			$lang = $this->get('zarafa/v1/main/language', LANG);
 			$lang = $Language->resolveLanguage($lang);
 
