@@ -262,6 +262,11 @@
 										$GLOBALS["bus"]->notify(bin2hex($messageProps[PR_PARENT_ENTRYID]), $basedate ? TABLE_SAVE : TABLE_DELETE, $messageProps);
 
 										break;
+                                    case "snooze":
+                                    case "dismiss":
+                                        $this->delete($store, $parententryid, $entryid, $action);
+                                        break;
+
 									default:
 										// Deleting an occurence means that we have to save the message to
 										// generate an exception. So when the basedate is provided, we actually
@@ -275,10 +280,6 @@
 										break;
 								}
 								break;
-
-							case "resolveConflict":
-								$this->resolveConflict($store, $parententryid, $entryid, $action);
-								break;
 							default:
 								$this->handleUnknownActionType($actionType);
 						}
@@ -347,26 +348,29 @@
 						break;
 
 					case 'delete':
-						if($e->getCode() == MAPI_E_NO_ACCESS) {
-							if (!empty($action['message_action']['action_type'])) {
-								switch($action['message_action']['action_type'])
-								{
-									case 'removeFromCalendar':
-										$e->setDisplayMessage(_('You have insufficient privileges to remove item from the calendar.'));
-										break;
+						switch ($e->getCode()) {
+							case MAPI_E_NO_ACCESS:
+								if (!empty($action['message_action']['action_type'])) {
+									switch($action['message_action']['action_type'])
+									{
+										case 'removeFromCalendar':
+											$e->setDisplayMessage(_('You have insufficient privileges to remove item from the calendar.'));
+											break;
+									}
 								}
-							}
+								break;
+							case MAPI_E_NOT_IN_QUEUE:
+								$e->setDisplayMessage(_('Message is no longer in the outgoing queue, typically because it has already been sent.'));
+								break;
+							case MAPI_E_UNABLE_TO_ABORT:
+								$e->setDisplayMessage(_('Message cannot be aborted'));
+								break;
 						}
-
 						if(empty($e->displayMessage)) {
 							$e->setDisplayMessage(_("You have insufficient privileges to delete items in this folder") . ".");
 						}
 						break;
 
-					case "resolveConflict":
-						$e->setDisplayMessage(_("Could not resolve conflict."));
-						break;
-
 					case "attach_items":
 						if($e->getCode() == MAPI_E_NO_ACCESS)
 							$e->setDisplayMessage(_("You have insufficient privileges to attach item as an attachment."));
@@ -589,8 +593,6 @@
 		 */
 		function delete($store, $parententryid, $entryid, $action)
 		{
-			$result = false;
-
 			if($store && $parententryid && $entryid) {
 				$props = array();
 				$props[PR_PARENT_ENTRYID] = $parententryid;
@@ -656,65 +658,6 @@
 			return $entryid;
 		}
 
-		function resolveConflict($store, $parententryid, $entryid, $action)
-		{
-
-			if(!is_array($entryid)) {
-				$entryid = array($entryid);
-			}
-			$srcmessage = mapi_openentry($GLOBALS["mapisession"]->getSession(), $entryid[0], 0);
-			if(!$srcmessage)
-				return false;
-
-			$dstmessage = mapi_openentry($GLOBALS["mapisession"]->getSession(), hex2bin($action["conflictentryid"]), MAPI_MODIFY);
-			if(!$dstmessage)
-				return false;
-
-			$srcfolder = mapi_openentry($GLOBALS["mapisession"]->getSession(), $parententryid, MAPI_MODIFY);
-
-			$result = mapi_copyto($srcmessage, array(), array(PR_CONFLICT_ITEMS, PR_SOURCE_KEY, PR_CHANGE_KEY, PR_PREDECESSOR_CHANGE_LIST), $dstmessage);
-			if(!$result)
-				return $result;
-
-			//remove srcmessage entryid from PR_CONFLICT_ITEMS
-			$props = mapi_getprops($dstmessage, array(PR_CONFLICT_ITEMS));
-			if(isset($props[PR_CONFLICT_ITEMS])){
-				$binentryid = hex2bin($entryid[0]);
-				foreach($props[PR_CONFLICT_ITEMS] as $i => $conflict){
-					if($conflict == $binentryid){
-						array_splice($props[PR_CONFLICT_ITEMS],$i,1);
-					}else{
-						$tmp = mapi_openentry($GLOBALS["mapisession"]->getSession(), $conflict, 0);
-						if(!$tmp){
-							array_splice($props[PR_CONFLICT_ITEMS],$i,1);
-						}
-						unset($tmp);
-					}
-				}
-				if(empty($props[PR_CONFLICT_ITEMS])){
-					mapi_setprops($dstmessage, $props);
-				}else{
-					mapi_deleteprops($dstmessage, array(PR_CONFLICT_ITEMS));
-				}
-			}
-
-
-			mapi_savechanges($dstmessage);
-
-			$result = mapi_folder_deletemessages($srcfolder, $entryid);
-
-			$props = array();
-			$props[PR_PARENT_ENTRYID] = $parententryid;
-			$props[PR_ENTRYID] = $entryid[0];
-
-			$storeprops = mapi_getprops($store, array(PR_ENTRYID));
-			$props[PR_STORE_ENTRYID] = $storeprops[PR_ENTRYID];
-			$GLOBALS["bus"]->notify(bin2hex($parententryid), TABLE_DELETE, $props);
-
-			if(!$result)
-				return $result;
-		}
-
 		/**
 		 * Function which copies or moves one or more items.
 		 * @param MAPIStore $store MAPI Message Store Object
@@ -758,6 +701,11 @@
 					$copyProps = Conversion::mapXML2MAPI($this->properties, $action["message_action"]["dropmodifications"]);
 				}
 
+				// if item has some changes made before choosing different calendar from create-in dropdown
+				if (isset($action["props"])) {
+					$copyProps = Conversion::mapXML2MAPI($this->properties, $action["props"]);
+				}
+
 				$props = array();
 				$props[PR_PARENT_ENTRYID] = $parententryid;
 				$props[PR_ENTRYID] = $entryids;
